Module internal

Module internal 

⚠️ INTERNAL! DO NOT USE!

This should not be considered part of this crate’s public API.

This is public only due to internal implementation requirements

Re-exports

pub use crate::core::option::Option::None;
pub use crate::core::option::Option::Some;
pub use crate::core::result::Result::Err;
pub use crate::core::result::Result::Ok;
pub use tokio;
pub use tracing;

Structs

ErrorPanicker
An uninhabited pseudo-Error-type that panics when any other error types to convert into it.
IteratorDropper
Drops an iterator without consuming any elements.

Enums

Option
The Option type. See the module level documentation for more.
Result
Result is a type that represents either success (Ok) or failure (Err).

Functions

entry_point